Contact class final

Two shapes, overlapping.

Constructors

Contact()

Properties

depth ↔ double
How far they overlap along normal.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
margin ↔ double
How close counts as a contact. See depth.
getter/setter pair
normal → Vector3
Points from A out of B — the direction A must move to separate.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
touching ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited